@@ -4,6 +4,7 @@ import fasteners
 from collections import OrderedDict, namedtuple
 
 from conans.errors import ConanException, NoRemoteAvailable
+from conans.model.ref import ConanFileReference
 from conans.util.files import load, save
 from conans.util.config_parser import get_bool_from_text_value
 from conans.util.log import logger
@@ -39,23 +40,23 @@ class RemoteRegistry(object):
             chunks = line.split()
             if not end_remotes:
                 if len(chunks) == 2:  # Retro compatibility
-                    ref, remote = chunks
+                    ref, remote_name = chunks
                     verify_ssl = "True"
                 elif len(chunks) == 3:
-                    ref, remote, verify_ssl = chunks
+                    ref, remote_name, verify_ssl = chunks
                 else:
                     raise ConanException("Bad file format, wrong item numbers in line '%s'" % line)
 
                 verify_ssl = get_bool_from_text_value(verify_ssl)
-                remotes[ref] = (remote, verify_ssl)
+                remotes[ref] = (remote_name, verify_ssl)
             else:
-                ref, remote = chunks
-                refs[ref] = remote
+                ref, remote_name = chunks
+                refs[ref] = remote_name
 
         return remotes, refs
 
     def _to_string(self, remotes, refs):
-        lines = ["%s %s %s" % (ref, remote, verify_ssl) for ref, (remote, verify_ssl) in remotes.items()]
+        lines = ["%s %s %s" % (ref, remote_name, verify_ssl) for ref, (remote_name, verify_ssl) in remotes.items()]
         lines.append("")
         lines.extend(["%s %s" % (ref, remote) for ref, remote in sorted(refs.items())])
         text = os.linesep.join(lines)
@@ -85,20 +86,20 @@ class RemoteRegistry(object):
     def remotes(self):
         return list(self._remote_dict.values())
 
-    def remote(self, name):
+    def remote(self, remote_name):
         try:
-            return self._remote_dict[name]
+            return self._remote_dict[remote_name]
         except KeyError:
             raise NoRemoteAvailable("No remote '%s' defined in remotes in file %s"
-                                    % (name, self._filename))
+                                    % (remote_name, self._filename))
 
     @property
     def _remote_dict(self):
         if self._remotes is None:
             with fasteners.InterProcessLock(self._filename + ".lock", logger=logger):
                 remotes, _ = self._load()
-                self._remotes = OrderedDict([(ref, Remote(ref, remote, verify_ssl))
-                                             for ref, (remote, verify_ssl) in remotes.items()])
+                self._remotes = OrderedDict([(ref, Remote(ref, remote_name, verify_ssl))
+                                             for ref, (remote_name, verify_ssl) in remotes.items()])
         return self._remotes
 
     @property
@@ -107,7 +108,8 @@ class RemoteRegistry(object):
             _, refs = self._load()
             return refs
 
-    def get_ref(self, conan_reference):
+    def get_recipe_remote(self, conan_reference):
+        assert(isinstance(conan_reference, ConanFileReference))
         with fasteners.InterProcessLock(self._filename + ".lock", logger=logger):
             remotes, refs = self._load()
             remote_name = refs.get(str(conan_reference))
@@ -117,44 +119,38 @@ class RemoteRegistry(object):
                 return None
 
     def remove_ref(self, conan_reference, quiet=False):
+        assert(isinstance(conan_reference, ConanFileReference))
         with fasteners.InterProcessLock(self._filename + ".lock", logger=logger):
-            conan_reference = str(conan_reference)
             remotes, refs = self._load()
             try:
-                del refs[conan_reference]
+                del refs[str(conan_reference)]
                 self._save(remotes, refs)
             except:
                 if not quiet:
                     self._output.warn("Couldn't delete '%s' from remote registry"
-                                      % conan_reference)
+                                      % str(conan_reference))
 
-    def set_ref(self, conan_reference, remote):
+    def set_ref(self, conan_reference, remote_name, check_exists=False):
+        assert(isinstance(conan_reference, ConanFileReference))
         with fasteners.InterProcessLock(self._filename + ".lock", logger=logger):
-            conan_reference = str(conan_reference)
             remotes, refs = self._load()
-            refs[conan_reference] = remote.name
+            if check_exists:
+                if conan_reference in refs:
+                    raise ConanException("%s already exists. Use update" % conan_reference)
+                if remote_name not in remotes:
+                    raise ConanException("%s not in remotes" % remote_name)
+            refs[str(conan_reference)] = remote_name
             self._save(remotes, refs)
 
-    def add_ref(self, conan_reference, remote):
+    def update_ref(self, conan_reference, remote_name):
+        assert(isinstance(conan_reference, ConanFileReference))
         with fasteners.InterProcessLock(self._filename + ".lock", logger=logger):
-            conan_reference = str(conan_reference)
             remotes, refs = self._load()
-            if conan_reference in refs:
-                raise ConanException("%s already exists. Use update" % conan_reference)
-            if remote not in remotes:
-                raise ConanException("%s not in remotes" % remote)
-            refs[conan_reference] = remote
-            self._save(remotes, refs)
-
-    def update_ref(self, conan_reference, remote):
-        with fasteners.InterProcessLock(self._filename + ".lock", logger=logger):
-            conan_reference = str(conan_reference)
-            remotes, refs = self._load()
-            if conan_reference not in refs:
-                raise ConanException("%s does not exist. Use add" % conan_reference)
-            if remote not in remotes:
-                raise ConanException("%s not in remotes" % remote)
-            refs[conan_reference] = remote
+            if str(conan_reference) not in refs:
+                raise ConanException("%s does not exist. Use add" % str(conan_reference))
+            if remote_name not in remotes:
+                raise ConanException("%s not in remotes" % remote_name)
+            refs[str(conan_reference)] = remote_name
             self._save(remotes, refs)
 
     def _upsert(self, remote_name, url, verify_ssl, insert):
