@@ -241,12 +241,13 @@ def vcvars_command(settings, arch=None, compiler_version=None, force=False, vcva
 
     # https://msdn.microsoft.com/en-us/library/f2ccy3wt.aspx
     arch_setting = arch_setting or 'x86_64'
-    if detected_architecture() == 'x86_64':
-        vcvars_arch = {'x86': 'x86',
+    arch_build = settings.get_safe("arch_build") or detected_architecture()
+    if arch_build == 'x86_64':
+        vcvars_arch = {'x86': 'amd64_x86' if int(compiler_version) >= 12 else 'x86',
                        'x86_64': 'amd64',
                        'armv7': 'amd64_arm',
                        'armv8': 'amd64_arm64'}.get(arch_setting)
-    elif detected_architecture() == 'x86':
+    elif arch_build == 'x86':
         vcvars_arch = {'x86': 'x86',
                        'x86_64': 'x86_amd64',
                        'armv7': 'x86_arm',
@@ -302,7 +303,7 @@ def vcvars_command(settings, arch=None, compiler_version=None, force=False, vcva
 
 def vcvars_dict(settings, arch=None, compiler_version=None, force=False, filter_known_paths=False,
                 vcvars_ver=None, winsdk_version=None, only_diff=True):
-
+    known_path_lists = ("INCLUDE", "LIB", "LIBPATH", "PATH")
     cmd = vcvars_command(settings, arch=arch,
                          compiler_version=compiler_version, force=force,
                          vcvars_ver=vcvars_ver, winsdk_version=winsdk_version) + " && echo __BEGINS__ && set"
@@ -320,8 +321,22 @@ def vcvars_dict(settings, arch=None, compiler_version=None, force=False, filter_
             continue
         try:
             name_var, value = line.split("=", 1)
-            if not only_diff or os.environ.get(name_var) != value:
-                new_env[name_var] = value
+            new_value = value.split(os.pathsep) if name_var in known_path_lists else value
+            # Return only new vars & changed ones, but only with the changed elements if the var is
+            # a list
+            if only_diff:
+                old_value = os.environ.get(name_var)
+                # The new value ends with separator and the old value, is a list, get only the
+                # new elements
+                if old_value and value.endswith(os.pathsep + old_value):
+                    new_env[name_var] = value[:-(len(old_value) + 1)].split(os.pathsep)
+                elif value != old_value:
+                    # Only if the vcvars changed something, we return the variable,
+                    # otherwise is not vcvars related
+                    new_env[name_var] = new_value
+            else:
+                new_env[name_var] = new_value
+
         except ValueError:
             pass
 
