@@ -451,6 +451,12 @@ class PackageOptions(object):
             except KeyError:
                 self._data.pop(k)
 
+    def initialize_patterns(self, values):
+        # Need to apply only those that exists
+        for option, value in values.items():
+            if option in self._data:
+                self._data[option].value = value
+
     def propagate_upstream(self, package_values, down_ref, own_ref, pattern_options):
         """
         :param: package_values: PackageOptionValues({"shared": "True"}
@@ -570,7 +576,7 @@ class Options(object):
                 pkg_values = self._deps_package_values.setdefault(name, PackageOptionValues())
                 pkg_values.propagate_upstream(option_values, down_ref, own_ref, name)
 
-    def initialize_upstream(self, user_values, local=False):
+    def initialize_upstream(self, user_values, local=False, name=None):
         """ used to propagate from downstream the options to the upper requirements
         """
         if user_values is not None:
@@ -579,6 +585,12 @@ class Options(object):
             if local:
                 self._package_options.set_local(user_values._package_values)
             else:
+                # This code is necessary to process patterns like *:shared=True
+                # To apply to the current consumer, which might not have name
+                for pattern, pkg_options in sorted(user_values._reqs_options.items()):
+                    if fnmatch.fnmatch(name or "", pattern):
+                        self._package_options.initialize_patterns(pkg_options)
+                # Then, the normal assignment of values, which could override patterns
                 self._package_options.values = user_values._package_values
             for package_name, package_values in user_values._reqs_options.items():
                 pkg_values = self._deps_package_values.setdefault(package_name, PackageOptionValues())
