@@ -18,7 +18,6 @@ from six.moves.urllib.parse import urlsplit, urlunsplit
 from webtest.app import TestApp
 
 from conans import __version__ as CLIENT_VERSION, tools
-from conans.client import settings_preprocessor
 from conans.client.client_cache import ClientCache
 from conans.client.command import Command
 from conans.client.conan_api import migrate_and_get_client_cache, Conan, get_request_timeout
@@ -70,6 +69,9 @@ class TestingResponse(object):
     def __init__(self, test_response):
         self.test_response = test_response
 
+    def close(self):
+        pass  # Compatibility with close() method of a requests when stream=True
+
     @property
     def headers(self):
         return self.test_response.headers
@@ -239,7 +241,7 @@ class TestServer(object):
 
     @property
     def paths(self):
-        return self.test_server.file_manager.paths
+        return self.test_server.server_store
 
     def __repr__(self):
         return "TestServer @ " + self.fake_url
@@ -278,17 +280,20 @@ class TestBufferConanOutput(ConanOutput):
         return value in self.__repr__()
 
 
-def create_local_git_repo(files, branch=None, submodules=None):
-    tmp = temp_folder()
-    save_files(tmp, files)
+def create_local_git_repo(files=None, branch=None, submodules=None, folder=None):
+    tmp = folder or temp_folder()
+    if files:
+        save_files(tmp, files)
     git = Git(tmp)
     git.run("init .")
-    if branch:
-        git.run("checkout -b %s" % branch)
-    git.run("add .")
     git.run('config user.email "you@example.com"')
     git.run('config user.name "Your Name"')
-    git.run('commit -m "message"')
+
+    if branch:
+        git.run("checkout -b %s" % branch)
+
+    git.run("add .")
+    git.run('commit -m  "commiting"')
 
     if submodules:
         for submodule in submodules:
@@ -400,6 +405,10 @@ class TestClient(object):
             if name != "default":
                 add_server_to_registry(name, server)
 
+    @property
+    def remote_registry(self):
+        return RemoteRegistry(self.client_cache.registry, TestBufferConanOutput())
+
     @property
     def paths(self):
         return self.client_cache
@@ -474,7 +483,7 @@ class TestClient(object):
             # Settings preprocessor
             interactive = not get_env("CONAN_NON_INTERACTIVE", False)
             conan = Conan(self.client_cache, self.user_io, self.runner, self.remote_manager,
-                          settings_preprocessor, interactive=interactive)
+                          interactive=interactive)
         outputer = CommandOutputer(self.user_io, self.client_cache)
         command = Command(conan, self.client_cache, self.user_io, outputer)
         args = shlex.split(command_line)
